@@ -54,6 +54,10 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/g/s-x{self.comId}/community/invitation?status={status}&start={start}&size={size}")
         return list(map(lambda o: InviteCode(**o), (await response.json())["communityInvitationList"]))
 
+    async def get_user_info(self, userId: str) -> UserProfile:
+        response = await self.get(f"/x{self.comId}/s/user-profile/{userId}")
+        return UserProfile(**(await response.json())["userProfile"])
+
     async def generate_invite_code(self, duration: int = 0, force: bool = True):
         data = {
             "duration": duration,
