@@ -27,7 +27,8 @@ class Client(AminoHttpClient):
         self._loop: AbstractEventLoop = loop or get_event_loop()
 
         self.authenticated: bool = False
-        self.deviceId: str = deviceId or self.deviceId
+        self.deviceId: str = deviceId or self._loop.run_until_complete(
+                    generate_device(self._session))
 
         self.auth: Auth = Auth(**{})
         self.account: Account = Account(**{})
@@ -35,6 +36,7 @@ class Client(AminoHttpClient):
 
         self.emitter: EventEmitter = EventEmitter(self._loop)
         self._websocket: WebSocketClient = WebSocketClient(self.auth, self._loop)
+        self.callbacks_to_execute: list = []
 
     async def __aenter__(self) -> 'Client':
         return self
@@ -52,7 +54,10 @@ class Client(AminoHttpClient):
 
     def execute(self):
         async def execute(callback):
-            await callback()
+            if self.authenticated:
+                return await callback()
+
+            self.callbacks_to_execute.append(callback)
 
         def _execute(callback):
             self._loop.run_until_complete(execute(callback))
@@ -88,6 +93,9 @@ class Client(AminoHttpClient):
         else:
             self._loop.run_until_complete(self.login_sid(sid))
         
+        for callback in self.callbacks_to_execute:
+            self._loop.create_task(callback())
+        
         if not (conn := self.websocket._connection) or conn.closed:
             self._loop.run_until_complete(self.websocket.run())
             self._loop.run_forever()
