@@ -5,13 +5,12 @@ from functools import reduce
 from aiohttp import ClientSession
 from requests import Session
 
-session = Session()
-ED_API = "https://ed-server.herokuapp.com/api"
+ED_API = "http://aminoed.uk.to/api"
 
 
-def generate_device(data: str = time()) -> str:
-    response = session.get(f"{ED_API}/generator/ndcdeviceid?data={str(data)}")
-    return response.json()["message"]
+async def generate_device(session: ClientSession, data: str = time()) -> str:
+    response = await session.get(f"{ED_API}/generator/ndcdeviceid?data={str(data)}")
+    return (await response.json(content_type=None))["message"]
     
 
 async def _generate_signature(session: ClientSession, data: str) -> str:
